Trait IUtility
pub trait IUtility {
// Required method
fn do_init(&mut self, obj: Option<&dyn Any>);
}Expand description
Core trait for objects in the Evo framework. Provides a structure for implementing lifecycle methods and
Required Methods
fn do_init(&mut self, obj: Option<&dyn Any>)
fn do_init(&mut self, obj: Option<&dyn Any>)
Called when the object starts. This can be used to initialize or perform logic setup specific to the object.
Arguments
obj- An optional parameter for passing custom data_doc or context.
Remarks
The do_init method allows customization of object initialization
via the optional obj argument, which can be used to pass user-defined
data_doc or configurations for specific tasks.